package it.tecnologieweb0708.appclasses;

public class SuperClass {

	// --- Class fields --------------------------------------------
	
	/**
	 * Class-valid field, whose value is the same for all object belonging
	 * to this class
	 */
	public static int staticField = 0;
	
	/**
	 * This is a constant value.
	 * It can be modified only at definition time
	 */
	public static final int CONSTANT_VALUE = 1;

	// --- Member fields ------------------------------------------
	
	/**
	 * This is a private member of objects of this class.
	 * Only accessible via modifier methods, also by subclasses objects!
	 */
	private int memberFieldA = 2;

	/**
	 * This is a protected member. Object of this class's subclasses
	 * can read and modify it directly
	 */
	protected int memberFieldB = 3;

	// --- Constructors -------------------------------------------
	
	/**
	 * Default constructor
	 * No arguments
	 */
	public SuperClass() {
		this.memberFieldA = 3;
	}

	/**
	 * This is one of the other possible constructors
	 * @param mfA the value for member field A of this object
	 */
	public SuperClass(int mfA) {
		this.memberFieldA = mfA;
	}

	// --- Getters and setters ------------------------------------

	/**
	 * This is a setter method, to modify memberFieldA
	 * Since mfA is private no one can read it as long as we don't provide
	 * a getter method.
	 * And if no logic within this class READS (!= use) memberFieldA value
	 * Eclipse will warn us that we are declaring unused variable
	 */
	public int getMemberFieldA() {
		return memberFieldA;
	}

	/**
	 * We can use source -> generate menus to automatically create getter
	 * and setter methods for the other member field
	 * @return memberFieldB value for the object of this class where the method is invoked
	 */
	public int getMemberFieldB() {
		return memberFieldB;
	}

	/**
	 * Setter method for memberFieldB
	 * @param memberFieldB
	 */
	public void setMemberFieldB(int memberFieldB) {
		this.memberFieldB = memberFieldB;
	}
	
}